/* -*- mode: c++; indent-tabs-mode: nil -*- */
/** @file XmlNode.qpp defines the XmlNode class */
/*
 QC_XmlNode.qpp
 
 Qore Programming Language
 
 Copyright 2003 - 2012 David Nichols
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include "qore-xml-module.h"

static QoreObject* doObject(QoreXmlNodeData *data) {
   return data ? new QoreObject(QC_XMLNODE, getProgram(), data) : 0;
}

#ifdef HAVE_XMLTEXTREADERSETSCHEMA
#define XML_CONST_HAVE_XMLTEXTREADERSETSCHEMA 1
#else
#define XML_CONST_HAVE_XMLTEXTREADERSETSCHEMA 0
#endif

#ifdef HAVE_XMLTEXTREADERRELAXNGSETSCHEMA
#define XML_CONST_HAVE_XMLTEXTREADERRELAXNGSETSCHEMA 1
#else
#define XML_CONST_HAVE_XMLTEXTREADERRELAXNGSETSCHEMA 0
#endif
/* Qore class Qore::Xml::XmlNode */

qore_classid_t CID_XMLNODE;
QoreClass* QC_XMLNODE;

// int XmlNode::childElementCount(){}
static int64 XmlNode_childElementCount(QoreObject* self, QoreXmlNodeData* xn, const QoreListNode* args, ExceptionSink* xsink) {
# 252 "QC_XmlNode.qpp"
    return xn->childElementCount();
}

// XmlNode::constructor() {}
static void XmlNode_constructor(QoreObject* self, const QoreListNode* args, ExceptionSink* xsink) {
# 232 "QC_XmlNode.qpp"
xsink->raiseException("XMLNODE-CONSTRUCTOR-ERROR", "this class cannot be constructed directly");
}

// XmlNode::copy() {}
static void XmlNode_copy(QoreObject* self, QoreObject* old, QoreXmlNodeData* xn, ExceptionSink* xsink) {
# 242 "QC_XmlNode.qpp"
self->setPrivate(CID_XMLNODE, new QoreXmlNodeData(*xn));
}

// *XmlNode XmlNode::firstElementChild(){}
static QoreObject* XmlNode_firstElementChild(QoreObject* self, QoreXmlNodeData* xn, const QoreListNode* args, ExceptionSink* xsink) {
# 300 "QC_XmlNode.qpp"
    return doObject(xn->firstElementChild());
}

// *string XmlNode::getContent(){}
static AbstractQoreNode* XmlNode_getContent(QoreObject* self, QoreXmlNodeData* xn, const QoreListNode* args, ExceptionSink* xsink) {
# 393 "QC_XmlNode.qpp"
    return xn->getContent();
}

// int XmlNode::getElementType(){}
static int64 XmlNode_getElementType(QoreObject* self, QoreXmlNodeData* xn, const QoreListNode* args, ExceptionSink* xsink) {
# 279 "QC_XmlNode.qpp"
    return xn->getElementType();
}

// *string XmlNode::getElementTypeName(){}
static AbstractQoreNode* XmlNode_getElementTypeName(QoreObject* self, QoreXmlNodeData* xn, const QoreListNode* args, ExceptionSink* xsink) {
# 289 "QC_XmlNode.qpp"
    const char *nt = get_xml_element_type_name((int)xn->getElementType());
   return nt ? new QoreStringNode(nt) : 0;
}

// *string XmlNode::getLang(){}
static AbstractQoreNode* XmlNode_getLang(QoreObject* self, QoreXmlNodeData* xn, const QoreListNode* args, ExceptionSink* xsink) {
# 413 "QC_XmlNode.qpp"
    return xn->getLang();
}

// *XmlNode XmlNode::getLastChild(){}
static QoreObject* XmlNode_getLastChild(QoreObject* self, QoreXmlNodeData* xn, const QoreListNode* args, ExceptionSink* xsink) {
# 310 "QC_XmlNode.qpp"
    return doObject(xn->getLastChild());
}

// *string XmlNode::getName(){}
static AbstractQoreNode* XmlNode_getName(QoreObject* self, QoreXmlNodeData* xn, const QoreListNode* args, ExceptionSink* xsink) {
# 403 "QC_XmlNode.qpp"
    return xn->getName();
}

// *string XmlNode::getNsProp(string prop, string ns){}
static AbstractQoreNode* XmlNode_getNsProp_VsVs(QoreObject* self, QoreXmlNodeData* xn, const QoreListNode* args, ExceptionSink* xsink) {
    const QoreStringNode* prop = HARD_QORE_STRING(args, 0);
    const QoreStringNode* ns = HARD_QORE_STRING(args, 1);
# 365 "QC_XmlNode.qpp"
    return xn->getNsProp(prop->getBuffer(), ns->getBuffer());
}

// string XmlNode::getPath(){}
static AbstractQoreNode* XmlNode_getPath(QoreObject* self, QoreXmlNodeData* xn, const QoreListNode* args, ExceptionSink* xsink) {
# 352 "QC_XmlNode.qpp"
    return xn->getPath(xsink);
}

// *string XmlNode::getProp(string prop){}
static AbstractQoreNode* XmlNode_getProp_Vs(QoreObject* self, QoreXmlNodeData* xn, const QoreListNode* args, ExceptionSink* xsink) {
    const QoreStringNode* prop = HARD_QORE_STRING(args, 0);
# 377 "QC_XmlNode.qpp"
    return xn->getProp(prop->getBuffer());
}

// int XmlNode::getSpacePreserve(){}
static int64 XmlNode_getSpacePreserve(QoreObject* self, QoreXmlNodeData* xn, const QoreListNode* args, ExceptionSink* xsink) {
# 262 "QC_XmlNode.qpp"
    return xn->getSpacePreserve();
}

// *string XmlNode::getXML(){}
static AbstractQoreNode* XmlNode_getXML(QoreObject* self, QoreXmlNodeData* xn, const QoreListNode* args, ExceptionSink* xsink) {
# 443 "QC_XmlNode.qpp"
    return xn->getXML();
}

// bool XmlNode::isBlank(){}
static bool XmlNode_isBlank(QoreObject* self, QoreXmlNodeData* xn, const QoreListNode* args, ExceptionSink* xsink) {
# 433 "QC_XmlNode.qpp"
    return xn->isBlank();
}

// bool XmlNode::isText(){}
static bool XmlNode_isText(QoreObject* self, QoreXmlNodeData* xn, const QoreListNode* args, ExceptionSink* xsink) {
# 423 "QC_XmlNode.qpp"
    return xn->isText();
}

// *XmlNode XmlNode::lastElementChild(){}
static QoreObject* XmlNode_lastElementChild(QoreObject* self, QoreXmlNodeData* xn, const QoreListNode* args, ExceptionSink* xsink) {
# 320 "QC_XmlNode.qpp"
    return doObject(xn->lastElementChild());
}

// *XmlNode XmlNode::nextElementSibling(){}
static QoreObject* XmlNode_nextElementSibling(QoreObject* self, QoreXmlNodeData* xn, const QoreListNode* args, ExceptionSink* xsink) {
# 330 "QC_XmlNode.qpp"
    return doObject(xn->nextElementSibling());
}

// *XmlNode XmlNode::previousElementSibling(){}
static QoreObject* XmlNode_previousElementSibling(QoreObject* self, QoreXmlNodeData* xn, const QoreListNode* args, ExceptionSink* xsink) {
# 340 "QC_XmlNode.qpp"
    return doObject(xn->previousElementSibling());
}

DLLLOCAL void preinitXmlNodeClass() {
    QC_XMLNODE = new QoreClass("XmlNode", QDOM_DEFAULT);
    CID_XMLNODE = QC_XMLNODE->getID();
    QC_XMLNODE->setSystem();
}

DLLLOCAL QoreClass* initXmlNodeClass(QoreNamespace& ns) {
    if (!QC_XMLNODE)
        preinitXmlNodeClass();

    // int XmlNode::childElementCount(){}
    QC_XMLNODE->addMethodExtended3("childElementCount", (q_method_int64_t)XmlNode_childElementCount, false, QC_CONSTANT, QDOM_DEFAULT, bigIntTypeInfo);

    // XmlNode::constructor() {}
    QC_XMLNODE->setConstructorExtended3(XmlNode_constructor, false, QC_NO_FLAGS, QDOM_DEFAULT);

    // XmlNode::copy() {}
    QC_XMLNODE->setCopy((q_copy_t)XmlNode_copy);

    // *XmlNode XmlNode::firstElementChild(){}
    QC_XMLNODE->addMethodExtended3("firstElementChild", (q_method_t)XmlNode_firstElementChild, false, QC_CONSTANT, QDOM_DEFAULT, QC_XMLNODE->getOrNothingTypeInfo());

    // *string XmlNode::getContent(){}
    QC_XMLNODE->addMethodExtended3("getContent", (q_method_t)XmlNode_getContent, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo);

    // int XmlNode::getElementType(){}
    QC_XMLNODE->addMethodExtended3("getElementType", (q_method_int64_t)XmlNode_getElementType, false, QC_CONSTANT, QDOM_DEFAULT, bigIntTypeInfo);

    // *string XmlNode::getElementTypeName(){}
    QC_XMLNODE->addMethodExtended3("getElementTypeName", (q_method_t)XmlNode_getElementTypeName, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo);

    // *string XmlNode::getLang(){}
    QC_XMLNODE->addMethodExtended3("getLang", (q_method_t)XmlNode_getLang, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo);

    // *XmlNode XmlNode::getLastChild(){}
    QC_XMLNODE->addMethodExtended3("getLastChild", (q_method_t)XmlNode_getLastChild, false, QC_CONSTANT, QDOM_DEFAULT, QC_XMLNODE->getOrNothingTypeInfo());

    // *string XmlNode::getName(){}
    QC_XMLNODE->addMethodExtended3("getName", (q_method_t)XmlNode_getName, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo);

    // *string XmlNode::getNsProp(string prop, string ns){}
    QC_XMLNODE->addMethodExtended3("getNsProp", (q_method_t)XmlNode_getNsProp_VsVs, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo, 2, stringTypeInfo, NULL, "prop", stringTypeInfo, NULL, "ns");

    // string XmlNode::getPath(){}
    QC_XMLNODE->addMethodExtended3("getPath", (q_method_t)XmlNode_getPath, false, QC_RET_VALUE_ONLY, QDOM_DEFAULT, stringTypeInfo);

    // *string XmlNode::getProp(string prop){}
    QC_XMLNODE->addMethodExtended3("getProp", (q_method_t)XmlNode_getProp_Vs, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo, 1, stringTypeInfo, NULL, "prop");

    // int XmlNode::getSpacePreserve(){}
    QC_XMLNODE->addMethodExtended3("getSpacePreserve", (q_method_int64_t)XmlNode_getSpacePreserve, false, QC_CONSTANT, QDOM_DEFAULT, bigIntTypeInfo);

    // *string XmlNode::getXML(){}
    QC_XMLNODE->addMethodExtended3("getXML", (q_method_t)XmlNode_getXML, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo);

    // bool XmlNode::isBlank(){}
    QC_XMLNODE->addMethodExtended3("isBlank", (q_method_bool_t)XmlNode_isBlank, false, QC_CONSTANT, QDOM_DEFAULT, boolTypeInfo);

    // bool XmlNode::isText(){}
    QC_XMLNODE->addMethodExtended3("isText", (q_method_bool_t)XmlNode_isText, false, QC_CONSTANT, QDOM_DEFAULT, boolTypeInfo);

    // *XmlNode XmlNode::lastElementChild(){}
    QC_XMLNODE->addMethodExtended3("lastElementChild", (q_method_t)XmlNode_lastElementChild, false, QC_CONSTANT, QDOM_DEFAULT, QC_XMLNODE->getOrNothingTypeInfo());

    // *XmlNode XmlNode::nextElementSibling(){}
    QC_XMLNODE->addMethodExtended3("nextElementSibling", (q_method_t)XmlNode_nextElementSibling, false, QC_CONSTANT, QDOM_DEFAULT, QC_XMLNODE->getOrNothingTypeInfo());

    // *XmlNode XmlNode::previousElementSibling(){}
    QC_XMLNODE->addMethodExtended3("previousElementSibling", (q_method_t)XmlNode_previousElementSibling, false, QC_CONSTANT, QDOM_DEFAULT, QC_XMLNODE->getOrNothingTypeInfo());
# 44 "QC_XmlNode.qpp"
# 51 "QC_XmlNode.qpp"
# 54 "QC_XmlNode.qpp"
# 57 "QC_XmlNode.qpp"
# 60 "QC_XmlNode.qpp"
# 63 "QC_XmlNode.qpp"
# 66 "QC_XmlNode.qpp"
# 69 "QC_XmlNode.qpp"
# 72 "QC_XmlNode.qpp"
# 75 "QC_XmlNode.qpp"
# 78 "QC_XmlNode.qpp"
# 81 "QC_XmlNode.qpp"
# 84 "QC_XmlNode.qpp"
# 87 "QC_XmlNode.qpp"
# 90 "QC_XmlNode.qpp"
# 93 "QC_XmlNode.qpp"
# 96 "QC_XmlNode.qpp"
# 99 "QC_XmlNode.qpp"
# 102 "QC_XmlNode.qpp"
# 105 "QC_XmlNode.qpp"
# 108 "QC_XmlNode.qpp"
# 111 "QC_XmlNode.qpp"
# 114 "QC_XmlNode.qpp"
    QoreHashNode* hash_ElementTypeMap = new QoreHashNode;
    hash_ElementTypeMap->setKeyValue("1", new QoreStringNode("XML_ELEMENT_NODE"), 0);
    hash_ElementTypeMap->setKeyValue("2", new QoreStringNode("XML_ATTRIBUTE_NODE"), 0);
    hash_ElementTypeMap->setKeyValue("3", new QoreStringNode("XML_TEXT_NODE"), 0);
    hash_ElementTypeMap->setKeyValue("4", new QoreStringNode("XML_CDATA_SECTION_NODE"), 0);
    hash_ElementTypeMap->setKeyValue("5", new QoreStringNode("XML_ENTITY_REF_NODE"), 0);
    hash_ElementTypeMap->setKeyValue("6", new QoreStringNode("XML_ENTITY_NODE"), 0);
    hash_ElementTypeMap->setKeyValue("7", new QoreStringNode("XML_PI_NODE"), 0);
    hash_ElementTypeMap->setKeyValue("8", new QoreStringNode("XML_COMMENT_NODE"), 0);
    hash_ElementTypeMap->setKeyValue("9", new QoreStringNode("XML_DOCUMENT_NODE"), 0);
    hash_ElementTypeMap->setKeyValue("10", new QoreStringNode("XML_DOCUMENT_TYPE_NODE"), 0);
    hash_ElementTypeMap->setKeyValue("11", new QoreStringNode("XML_DOCUMENT_FRAG_NODE"), 0);
    hash_ElementTypeMap->setKeyValue("12", new QoreStringNode("XML_NOTATION_NODE"), 0);
    hash_ElementTypeMap->setKeyValue("13", new QoreStringNode("XML_HTML_DOCUMENT_NODE"), 0);
    hash_ElementTypeMap->setKeyValue("14", new QoreStringNode("XML_DTD_NODE"), 0);
    hash_ElementTypeMap->setKeyValue("15", new QoreStringNode("XML_ELEMENT_DECL"), 0);
    hash_ElementTypeMap->setKeyValue("16", new QoreStringNode("XML_ATTRIBUTE_DECL"), 0);
    hash_ElementTypeMap->setKeyValue("17", new QoreStringNode("XML_ENTITY_DECL"), 0);
    hash_ElementTypeMap->setKeyValue("18", new QoreStringNode("XML_NAMESPACE_DECL"), 0);
    hash_ElementTypeMap->setKeyValue("19", new QoreStringNode("XML_XINCLUDE_START"), 0);
    hash_ElementTypeMap->setKeyValue("20", new QoreStringNode("XML_XINCLUDE_END"), 0);
    hash_ElementTypeMap->setKeyValue("21", new QoreStringNode("XML_DOCB_DOCUMENT_NODE"), 0);

    ns.addConstant("ElementTypeMap", hash_ElementTypeMap);
    ns.addConstant("XML_ATTRIBUTE_DECL", new QoreBigIntNode(XML_ATTRIBUTE_DECL));
    ns.addConstant("XML_ATTRIBUTE_NODE", new QoreBigIntNode(XML_ATTRIBUTE_NODE));
    ns.addConstant("XML_CDATA_SECTION_NODE", new QoreBigIntNode(XML_CDATA_SECTION_NODE));
    ns.addConstant("XML_COMMENT_NODE", new QoreBigIntNode(XML_COMMENT_NODE));
    ns.addConstant("XML_DOCB_DOCUMENT_NODE", new QoreBigIntNode(XML_DOCB_DOCUMENT_NODE));
    ns.addConstant("XML_DOCUMENT_FRAG_NODE", new QoreBigIntNode(XML_DOCUMENT_FRAG_NODE));
    ns.addConstant("XML_DOCUMENT_NODE", new QoreBigIntNode(XML_DOCUMENT_NODE));
    ns.addConstant("XML_DOCUMENT_TYPE_NODE", new QoreBigIntNode(XML_DOCUMENT_TYPE_NODE));
    ns.addConstant("XML_DTD_NODE", new QoreBigIntNode(XML_DTD_NODE));
    ns.addConstant("XML_ELEMENT_DECL", new QoreBigIntNode(XML_ELEMENT_DECL));
    ns.addConstant("XML_ELEMENT_NODE", new QoreBigIntNode(XML_ELEMENT_NODE));
    ns.addConstant("XML_ENTITY_DECL", new QoreBigIntNode(XML_ENTITY_DECL));
    ns.addConstant("XML_ENTITY_NODE", new QoreBigIntNode(XML_ENTITY_NODE));
    ns.addConstant("XML_ENTITY_REF_NODE", new QoreBigIntNode(XML_ENTITY_REF_NODE));
    ns.addConstant("XML_HTML_DOCUMENT_NODE", new QoreBigIntNode(XML_HTML_DOCUMENT_NODE));
    ns.addConstant("XML_NAMESPACE_DECL", new QoreBigIntNode(XML_NAMESPACE_DECL));
    ns.addConstant("XML_NOTATION_NODE", new QoreBigIntNode(XML_NOTATION_NODE));
    ns.addConstant("XML_PI_NODE", new QoreBigIntNode(XML_PI_NODE));
    ns.addConstant("XML_TEXT_NODE", new QoreBigIntNode(XML_TEXT_NODE));
    ns.addConstant("XML_XINCLUDE_END", new QoreBigIntNode(XML_XINCLUDE_END));
    ns.addConstant("XML_XINCLUDE_START", new QoreBigIntNode(XML_XINCLUDE_START));
# 140 "QC_XmlNode.qpp"
# 147 "QC_XmlNode.qpp"
# 150 "QC_XmlNode.qpp"
# 153 "QC_XmlNode.qpp"
# 156 "QC_XmlNode.qpp"
# 159 "QC_XmlNode.qpp"
# 162 "QC_XmlNode.qpp"
# 165 "QC_XmlNode.qpp"
# 168 "QC_XmlNode.qpp"
# 171 "QC_XmlNode.qpp"
# 174 "QC_XmlNode.qpp"
# 177 "QC_XmlNode.qpp"
# 180 "QC_XmlNode.qpp"
# 183 "QC_XmlNode.qpp"
# 186 "QC_XmlNode.qpp"
# 189 "QC_XmlNode.qpp"
# 192 "QC_XmlNode.qpp"
# 195 "QC_XmlNode.qpp"
# 198 "QC_XmlNode.qpp"
# 201 "QC_XmlNode.qpp"
    QoreHashNode* hash_NodeTypeMap = new QoreHashNode;
    hash_NodeTypeMap->setKeyValue("0", new QoreStringNode("XML_NODE_TYPE_NONE"), 0);
    hash_NodeTypeMap->setKeyValue("1", new QoreStringNode("XML_NODE_TYPE_ELEMENT"), 0);
    hash_NodeTypeMap->setKeyValue("2", new QoreStringNode("XML_NODE_TYPE_ATTRIBUTE"), 0);
    hash_NodeTypeMap->setKeyValue("3", new QoreStringNode("XML_NODE_TYPE_TEXT"), 0);
    hash_NodeTypeMap->setKeyValue("4", new QoreStringNode("XML_NODE_TYPE_CDATA"), 0);
    hash_NodeTypeMap->setKeyValue("5", new QoreStringNode("XML_NODE_TYPE_ENTITY_REFERENCE"), 0);
    hash_NodeTypeMap->setKeyValue("6", new QoreStringNode("XML_NODE_TYPE_ENTITY"), 0);
    hash_NodeTypeMap->setKeyValue("7", new QoreStringNode("XML_NODE_TYPE_PROCESSING_INSTRUCTION"), 0);
    hash_NodeTypeMap->setKeyValue("8", new QoreStringNode("XML_NODE_TYPE_COMMENT"), 0);
    hash_NodeTypeMap->setKeyValue("9", new QoreStringNode("XML_NODE_TYPE_DOCUMENT"), 0);
    hash_NodeTypeMap->setKeyValue("10", new QoreStringNode("XML_NODE_TYPE_DOCUMENT_TYPE"), 0);
    hash_NodeTypeMap->setKeyValue("11", new QoreStringNode("XML_NODE_TYPE_DOCUMENT_FRAGMENT"), 0);
    hash_NodeTypeMap->setKeyValue("12", new QoreStringNode("XML_NODE_TYPE_NOTATION"), 0);
    hash_NodeTypeMap->setKeyValue("13", new QoreStringNode("XML_NODE_TYPE_WHITESPACE"), 0);
    hash_NodeTypeMap->setKeyValue("14", new QoreStringNode("XML_NODE_TYPE_SIGNIFICANT_WHITESPACE"), 0);
    hash_NodeTypeMap->setKeyValue("15", new QoreStringNode("XML_NODE_TYPE_END_ELEMENT"), 0);
    hash_NodeTypeMap->setKeyValue("16", new QoreStringNode("XML_NODE_TYPE_END_ENTITY"), 0);
    hash_NodeTypeMap->setKeyValue("17", new QoreStringNode("XML_NODE_TYPE_XML_DECLARATION"), 0);

    ns.addConstant("NodeTypeMap", hash_NodeTypeMap);
    ns.addConstant("XML_NODE_TYPE_ATTRIBUTE", new QoreBigIntNode(XML_READER_TYPE_ATTRIBUTE));
    ns.addConstant("XML_NODE_TYPE_CDATA", new QoreBigIntNode(XML_READER_TYPE_CDATA));
    ns.addConstant("XML_NODE_TYPE_COMMENT", new QoreBigIntNode(XML_READER_TYPE_COMMENT));
    ns.addConstant("XML_NODE_TYPE_DOCUMENT", new QoreBigIntNode(XML_READER_TYPE_DOCUMENT));
    ns.addConstant("XML_NODE_TYPE_DOCUMENT_FRAGMENT", new QoreBigIntNode(XML_READER_TYPE_DOCUMENT_FRAGMENT));
    ns.addConstant("XML_NODE_TYPE_DOCUMENT_TYPE", new QoreBigIntNode(XML_READER_TYPE_DOCUMENT_TYPE));
    ns.addConstant("XML_NODE_TYPE_ELEMENT", new QoreBigIntNode(XML_READER_TYPE_ELEMENT));
    ns.addConstant("XML_NODE_TYPE_END_ELEMENT", new QoreBigIntNode(XML_READER_TYPE_END_ELEMENT));
    ns.addConstant("XML_NODE_TYPE_END_ENTITY", new QoreBigIntNode(XML_READER_TYPE_END_ENTITY));
    ns.addConstant("XML_NODE_TYPE_ENTITY", new QoreBigIntNode(XML_READER_TYPE_ENTITY));
    ns.addConstant("XML_NODE_TYPE_ENTITY_REFERENCE", new QoreBigIntNode(XML_READER_TYPE_ENTITY_REFERENCE));
    ns.addConstant("XML_NODE_TYPE_NONE", new QoreBigIntNode(XML_READER_TYPE_NONE));
    ns.addConstant("XML_NODE_TYPE_NOTATION", new QoreBigIntNode(XML_READER_TYPE_NOTATION));
    ns.addConstant("XML_NODE_TYPE_PROCESSING_INSTRUCTION", new QoreBigIntNode(XML_READER_TYPE_PROCESSING_INSTRUCTION));
    ns.addConstant("XML_NODE_TYPE_SIGNIFICANT_WHITESPACE", new QoreBigIntNode(XML_READER_TYPE_SIGNIFICANT_WHITESPACE));
    ns.addConstant("XML_NODE_TYPE_TEXT", new QoreBigIntNode(XML_READER_TYPE_TEXT));
    ns.addConstant("XML_NODE_TYPE_WHITESPACE", new QoreBigIntNode(XML_READER_TYPE_WHITESPACE));
    ns.addConstant("XML_NODE_TYPE_XML_DECLARATION", new QoreBigIntNode(XML_READER_TYPE_XML_DECLARATION));

    return QC_XMLNODE;
}
/*
// line numbers are not activated by default and no option is provided to activate them
int XmlNode::getLineNumber() {
   return xn->getLineNumber();
}
*/

/*
static AbstractQoreNode *XMLNODE_getBase(QoreObject *self, QoreXmlNodeData *xn, const QoreListNode *params, ExceptionSink *xsink) {
   return xn->getBase();
}
*/
