/* -*- mode: c++; indent-tabs-mode: nil -*- */
/** @file XmlReader.qpp defines the XmlReader class */
/*
  QC_XmlReader.qpp

  Qore Programming Language
  
  Copyright 2003 - 2012 David Nichols

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.
  
  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.
  
  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "qore-xml-module.h"

#include "QC_XmlReader.h"
#include "QC_XmlNode.h"
#include "ql_xml.h"
/* Qore class Qore::Xml::XmlReader */

qore_classid_t CID_XMLREADER;
QoreClass* QC_XMLREADER;

// int XmlReader::attributeCount(){}
static int64 XmlReader_attributeCount(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 282 "QC_XmlReader.qpp"
    return xr->attributeCount();
}

// *string XmlReader::baseUri(){}
static AbstractQoreNode* XmlReader_baseUri(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 292 "QC_XmlReader.qpp"
    const char *n = xr->baseUri();
   return n ? new QoreStringNode(n, QCS_UTF8) : 0;
}

// XmlReader::constructor(XmlDoc doc) {}
static void XmlReader_constructor_C6XmlDoc(QoreObject* self, const QoreListNode* args, ExceptionSink* xsink) {
    HARD_QORE_OBJ_DATA(doc, QoreXmlDocData, args, 0, CID_XMLDOC, "XmlReader::constructor()", "XmlDoc", xsink);
    if (*xsink)
        return;
# 43 "QC_XmlReader.qpp"
ReferenceHolder<QoreXmlDocData> doc_holder(doc, xsink);

   SimpleRefHolder<QoreXmlReaderData> xr(new QoreXmlReaderData(doc, xsink));
   if (*xsink)
      return;

   self->setPrivate(CID_XMLREADER, xr.release());
}

// XmlReader::constructor(string xml) {}
static void XmlReader_constructor_Vs(QoreObject* self, const QoreListNode* args, ExceptionSink* xsink) {
    const QoreStringNode* xml = HARD_QORE_STRING(args, 0);
# 60 "QC_XmlReader.qpp"
// FIXME: there is no TempNodeEncodingHelper class :(
   QoreStringNode* xarg;
   if (xml->getEncoding() == QCS_UTF8)
      xarg = xml->stringRefSelf();
   else {
      xarg = xml->convertEncoding(QCS_UTF8, xsink);
      if (!xarg)
         return;
   }

   SimpleRefHolder<QoreXmlReaderData> xr(new QoreXmlReaderData(xarg, xsink));
   if (*xsink)
      return;

   self->setPrivate(CID_XMLREADER, xr.release());
}

// XmlReader::copy() {}
static void XmlReader_copy(QoreObject* self, QoreObject* old, QoreXmlReaderData* xr, ExceptionSink* xsink) {
# 84 "QC_XmlReader.qpp"
ReferenceHolder<QoreXmlReaderData> doc(xr->copy(xsink), xsink);
   if (!*xsink)
      self->setPrivate(CID_XMLREADER, doc.release());
}

// int XmlReader::depth(){}
static int64 XmlReader_depth(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 156 "QC_XmlReader.qpp"
    return xr->depth();
}

// *string XmlReader::encoding(){}
static AbstractQoreNode* XmlReader_encoding(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 305 "QC_XmlReader.qpp"
    const char *n = xr->encoding();
   return n ? new QoreStringNode(n, QCS_UTF8) : 0;
}

// *string XmlReader::getAttribute(string attr){}
static AbstractQoreNode* XmlReader_getAttribute_Vs(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
    const QoreStringNode* attr = HARD_QORE_STRING(args, 0);
# 375 "QC_XmlReader.qpp"
    return xr->getAttribute(attr->getBuffer());
}

// *string XmlReader::getAttributeNs(string attr, string ns){}
static AbstractQoreNode* XmlReader_getAttributeNs_VsVs(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
    const QoreStringNode* attr = HARD_QORE_STRING(args, 0);
    const QoreStringNode* ns = HARD_QORE_STRING(args, 1);
# 404 "QC_XmlReader.qpp"
    return xr->getAttributeNs(attr->getBuffer(), ns->getBuffer());
}

// *string XmlReader::getAttributeOffset(softint offset = 0){}
static AbstractQoreNode* XmlReader_getAttributeOffset_vi(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
    int64 offset = HARD_QORE_INT(args, 0);
# 389 "QC_XmlReader.qpp"
    return xr->getAttributeOffset((int)offset);
}

// *string XmlReader::getInnerXml(){}
static AbstractQoreNode* XmlReader_getInnerXml(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 549 "QC_XmlReader.qpp"
    return xr->getInnerXml();
}

// *string XmlReader::getOuterXml(){}
static AbstractQoreNode* XmlReader_getOuterXml(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 561 "QC_XmlReader.qpp"
    return xr->getOuterXml();
}

// bool XmlReader::hasAttributes(){}
static bool XmlReader_hasAttributes(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 190 "QC_XmlReader.qpp"
    return xr->hasAttributes();
}

// bool XmlReader::hasValue(){}
static bool XmlReader_hasValue(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 200 "QC_XmlReader.qpp"
    return xr->hasValue();
}

// bool XmlReader::isDefault(){}
static bool XmlReader_isDefault(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 210 "QC_XmlReader.qpp"
    return xr->isDefault();
}

// bool XmlReader::isEmptyElement(){}
static bool XmlReader_isEmptyElement(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 220 "QC_XmlReader.qpp"
    return xr->isEmptyElement();
}

// bool XmlReader::isNamespaceDecl(){}
static bool XmlReader_isNamespaceDecl(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 230 "QC_XmlReader.qpp"
    return xr->isNamespaceDecl();
}

// bool XmlReader::isValid(){}
static bool XmlReader_isValid(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 240 "QC_XmlReader.qpp"
    return xr->isValid();
}

// *string XmlReader::localName(){}
static AbstractQoreNode* XmlReader_localName(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 316 "QC_XmlReader.qpp"
    const char *n = xr->localName();
   return n ? new QoreStringNode(n, QCS_UTF8) : 0;
}

// *string XmlReader::lookupNamespace(){}
static AbstractQoreNode* XmlReader_lookupNamespace(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 414 "QC_XmlReader.qpp"
    return xr->lookupNamespace(0);
}

// *string XmlReader::lookupNamespace(string prefix){}
static AbstractQoreNode* XmlReader_lookupNamespace_Vs(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
    const QoreStringNode* prefix = HARD_QORE_STRING(args, 0);
# 426 "QC_XmlReader.qpp"
    return xr->lookupNamespace(prefix->getBuffer());
}

// bool XmlReader::moveToAttribute(string attr){}
static bool XmlReader_moveToAttribute_Vs(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
    const QoreStringNode* attr = HARD_QORE_STRING(args, 0);
# 444 "QC_XmlReader.qpp"
    return xr->moveToAttribute(attr->getBuffer(), xsink);
}

// bool XmlReader::moveToAttributeNs(string attr, string ns){}
static bool XmlReader_moveToAttributeNs_VsVs(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
    const QoreStringNode* attr = HARD_QORE_STRING(args, 0);
    const QoreStringNode* ns = HARD_QORE_STRING(args, 1);
# 481 "QC_XmlReader.qpp"
    return xr->moveToAttributeNs(attr->getBuffer(), ns->getBuffer(), xsink);
}

// bool XmlReader::moveToAttributeOffset(softint offset){}
static bool XmlReader_moveToAttributeOffset_vi(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
    int64 offset = HARD_QORE_INT(args, 0);
# 462 "QC_XmlReader.qpp"
    return xr->moveToAttributeOffset((int)offset, xsink);
}

// bool XmlReader::moveToElement(){}
static bool XmlReader_moveToElement(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 495 "QC_XmlReader.qpp"
    return xr->moveToElement(xsink);
}

// bool XmlReader::moveToFirstAttribute(){}
static bool XmlReader_moveToFirstAttribute(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 509 "QC_XmlReader.qpp"
    return xr->moveToFirstAttribute(xsink);
}

// bool XmlReader::moveToNextAttribute(){}
static bool XmlReader_moveToNextAttribute(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 523 "QC_XmlReader.qpp"
    return xr->moveToNextAttribute(xsink);
}

// *string XmlReader::name(){}
static AbstractQoreNode* XmlReader_name(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 168 "QC_XmlReader.qpp"
    const char *n = xr->constName();
   return n ? new QoreStringNode(n, QCS_UTF8) : 0;
}

// *string XmlReader::namespaceUri(){}
static AbstractQoreNode* XmlReader_namespaceUri(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 327 "QC_XmlReader.qpp"
    const char *n = xr->namespaceUri();
   return n ? new QoreStringNode(n, QCS_UTF8) : 0;
}

// bool XmlReader::next(){}
static bool XmlReader_next(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 537 "QC_XmlReader.qpp"
    return xr->next(xsink);
}

// int XmlReader::nodeType(){}
static int64 XmlReader_nodeType(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 133 "QC_XmlReader.qpp"
    return xr->nodeType();
}

// *string XmlReader::nodeTypeName(){}
static AbstractQoreNode* XmlReader_nodeTypeName(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 145 "QC_XmlReader.qpp"
    const char *n = get_xml_node_type_name(xr->nodeType());
   return n ? new QoreStringNode(n) : 0;
}

// *string XmlReader::prefix(){}
static AbstractQoreNode* XmlReader_prefix(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 338 "QC_XmlReader.qpp"
    const char *n = xr->prefix();
   return n ? new QoreStringNode(n, QCS_UTF8) : 0;
}

// bool XmlReader::read(){}
static bool XmlReader_read(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 103 "QC_XmlReader.qpp"
    return xr->read(xsink);
}

// bool XmlReader::readSkipWhitespace(){}
static bool XmlReader_readSkipWhitespace(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 120 "QC_XmlReader.qpp"
    return xr->readSkipWhitespace(xsink) ? false : true;
}

// nothing XmlReader::relaxNGValidate(string relaxng){}
static AbstractQoreNode* XmlReader_relaxNGValidate_Vs(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
    const QoreStringNode* relaxng = HARD_QORE_STRING(args, 0);
# 578 "QC_XmlReader.qpp"
    #ifdef HAVE_XMLTEXTREADERRELAXNGSETSCHEMA
   xr->relaxNGValidate(relaxng->getBuffer(), xsink);
#else
   xsink->raiseException("MISSING-FEATURE-ERROR", "the libxml2 version used to compile the qore library did not support the xmlTextReaderRelaxNGValidate() function, therefore XmlReader::relaxNGValidate() is not available in Qore; for maximum portability, use the constant Option::HAVE_PARSEXMLWITHRELAXNG to check if this method is implemented before calling");
#endif
   return 0;
}

// nothing XmlReader::schemaValidate(string xsd){}
static AbstractQoreNode* XmlReader_schemaValidate_Vs(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
    const QoreStringNode* xsd = HARD_QORE_STRING(args, 0);
# 600 "QC_XmlReader.qpp"
    #ifdef HAVE_XMLTEXTREADERSETSCHEMA
   xr->schemaValidate(xsd->getBuffer(), xsink);
#else
   xsink->raiseException("MISSING-FEATURE-ERROR", "the libxml2 version used to compile the qore library did not support the xmlTextReaderSchemaValidate() function, therefore XmlReader::schemaValidate() is not available in Qore; for maximum portability, use the constant Option::HAVE_PARSEXMLWITHSCHEMA to check if this method is implemented before calling");
#endif
   return 0;
}

// any XmlReader::toQore(){}
static AbstractQoreNode* XmlReader_toQore(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 256 "QC_XmlReader.qpp"
    return xr->parseXMLData(QCS_UTF8, false, xsink);
}

// any XmlReader::toQoreData(){}
static AbstractQoreNode* XmlReader_toQoreData(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 272 "QC_XmlReader.qpp"
    return xr->parseXMLData(QCS_UTF8, true, xsink);
}

// *string XmlReader::value(){}
static AbstractQoreNode* XmlReader_value(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 179 "QC_XmlReader.qpp"
    const char *n = xr->constValue();
   return n ? new QoreStringNode(n, QCS_UTF8) : 0;
}

// *string XmlReader::xmlLang(){}
static AbstractQoreNode* XmlReader_xmlLang(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 349 "QC_XmlReader.qpp"
    const char *n = xr->xmlLang();
   return n ? new QoreStringNode(n, QCS_UTF8) : 0;
}

// *string XmlReader::xmlVersion(){}
static AbstractQoreNode* XmlReader_xmlVersion(QoreObject* self, QoreXmlReaderData* xr, const QoreListNode* args, ExceptionSink* xsink) {
# 360 "QC_XmlReader.qpp"
    const char *n = xr->xmlVersion();
   return n ? new QoreStringNode(n, QCS_UTF8) : 0;
}

DLLLOCAL void preinitXmlReaderClass() {
    QC_XMLREADER = new QoreClass("XmlReader", QDOM_DEFAULT);
    CID_XMLREADER = QC_XMLREADER->getID();
    QC_XMLREADER->setSystem();
}

DLLLOCAL QoreClass* initXmlReaderClass(QoreNamespace& ns) {
    if (!QC_XMLREADER)
        preinitXmlReaderClass();

    // int XmlReader::attributeCount(){}
    QC_XMLREADER->addMethodExtended3("attributeCount", (q_method_int64_t)XmlReader_attributeCount, false, QC_CONSTANT, QDOM_DEFAULT, bigIntTypeInfo);

    // *string XmlReader::baseUri(){}
    QC_XMLREADER->addMethodExtended3("baseUri", (q_method_t)XmlReader_baseUri, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo);

    // XmlReader::constructor(XmlDoc doc) {}
    QC_XMLREADER->setConstructorExtended3(XmlReader_constructor_C6XmlDoc, false, QC_NO_FLAGS, QDOM_DEFAULT, 1, QC_XMLDOC->getTypeInfo(), NULL, "doc");

    // XmlReader::constructor(string xml) {}
    QC_XMLREADER->setConstructorExtended3(XmlReader_constructor_Vs, false, QC_NO_FLAGS, QDOM_DEFAULT, 1, stringTypeInfo, NULL, "xml");

    // XmlReader::copy() {}
    QC_XMLREADER->setCopy((q_copy_t)XmlReader_copy);

    // int XmlReader::depth(){}
    QC_XMLREADER->addMethodExtended3("depth", (q_method_int64_t)XmlReader_depth, false, QC_CONSTANT, QDOM_DEFAULT, bigIntTypeInfo);

    // *string XmlReader::encoding(){}
    QC_XMLREADER->addMethodExtended3("encoding", (q_method_t)XmlReader_encoding, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo);

    // *string XmlReader::getAttribute(string attr){}
    QC_XMLREADER->addMethodExtended3("getAttribute", (q_method_t)XmlReader_getAttribute_Vs, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo, 1, stringTypeInfo, NULL, "attr");

    // *string XmlReader::getAttributeNs(string attr, string ns){}
    QC_XMLREADER->addMethodExtended3("getAttributeNs", (q_method_t)XmlReader_getAttributeNs_VsVs, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo, 2, stringTypeInfo, NULL, "attr", stringTypeInfo, NULL, "ns");

    // *string XmlReader::getAttributeOffset(softint offset = 0){}
    QC_XMLREADER->addMethodExtended3("getAttributeOffset", (q_method_t)XmlReader_getAttributeOffset_vi, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo, 1, softBigIntTypeInfo, zero(), "offset");

    // *string XmlReader::getInnerXml(){}
    QC_XMLREADER->addMethodExtended3("getInnerXml", (q_method_t)XmlReader_getInnerXml, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo);

    // *string XmlReader::getOuterXml(){}
    QC_XMLREADER->addMethodExtended3("getOuterXml", (q_method_t)XmlReader_getOuterXml, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo);

    // bool XmlReader::hasAttributes(){}
    QC_XMLREADER->addMethodExtended3("hasAttributes", (q_method_bool_t)XmlReader_hasAttributes, false, QC_CONSTANT, QDOM_DEFAULT, boolTypeInfo);

    // bool XmlReader::hasValue(){}
    QC_XMLREADER->addMethodExtended3("hasValue", (q_method_bool_t)XmlReader_hasValue, false, QC_CONSTANT, QDOM_DEFAULT, boolTypeInfo);

    // bool XmlReader::isDefault(){}
    QC_XMLREADER->addMethodExtended3("isDefault", (q_method_bool_t)XmlReader_isDefault, false, QC_CONSTANT, QDOM_DEFAULT, boolTypeInfo);

    // bool XmlReader::isEmptyElement(){}
    QC_XMLREADER->addMethodExtended3("isEmptyElement", (q_method_bool_t)XmlReader_isEmptyElement, false, QC_CONSTANT, QDOM_DEFAULT, boolTypeInfo);

    // bool XmlReader::isNamespaceDecl(){}
    QC_XMLREADER->addMethodExtended3("isNamespaceDecl", (q_method_bool_t)XmlReader_isNamespaceDecl, false, QC_CONSTANT, QDOM_DEFAULT, boolTypeInfo);

    // bool XmlReader::isValid(){}
    QC_XMLREADER->addMethodExtended3("isValid", (q_method_bool_t)XmlReader_isValid, false, QC_CONSTANT, QDOM_DEFAULT, boolTypeInfo);

    // *string XmlReader::localName(){}
    QC_XMLREADER->addMethodExtended3("localName", (q_method_t)XmlReader_localName, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo);

    // *string XmlReader::lookupNamespace(){}
    QC_XMLREADER->addMethodExtended3("lookupNamespace", (q_method_t)XmlReader_lookupNamespace, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo);

    // *string XmlReader::lookupNamespace(string prefix){}
    QC_XMLREADER->addMethodExtended3("lookupNamespace", (q_method_t)XmlReader_lookupNamespace_Vs, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo, 1, stringTypeInfo, NULL, "prefix");

    // bool XmlReader::moveToAttribute(string attr){}
    QC_XMLREADER->addMethodExtended3("moveToAttribute", (q_method_bool_t)XmlReader_moveToAttribute_Vs, false, QC_NO_FLAGS, QDOM_DEFAULT, boolTypeInfo, 1, stringTypeInfo, NULL, "attr");

    // bool XmlReader::moveToAttributeNs(string attr, string ns){}
    QC_XMLREADER->addMethodExtended3("moveToAttributeNs", (q_method_bool_t)XmlReader_moveToAttributeNs_VsVs, false, QC_NO_FLAGS, QDOM_DEFAULT, boolTypeInfo, 2, stringTypeInfo, NULL, "attr", stringTypeInfo, NULL, "ns");

    // bool XmlReader::moveToAttributeOffset(softint offset){}
    QC_XMLREADER->addMethodExtended3("moveToAttributeOffset", (q_method_bool_t)XmlReader_moveToAttributeOffset_vi, false, QC_NO_FLAGS, QDOM_DEFAULT, boolTypeInfo, 1, softBigIntTypeInfo, NULL, "offset");

    // bool XmlReader::moveToElement(){}
    QC_XMLREADER->addMethodExtended3("moveToElement", (q_method_bool_t)XmlReader_moveToElement, false, QC_NO_FLAGS, QDOM_DEFAULT, boolTypeInfo);

    // bool XmlReader::moveToFirstAttribute(){}
    QC_XMLREADER->addMethodExtended3("moveToFirstAttribute", (q_method_bool_t)XmlReader_moveToFirstAttribute, false, QC_NO_FLAGS, QDOM_DEFAULT, boolTypeInfo);

    // bool XmlReader::moveToNextAttribute(){}
    QC_XMLREADER->addMethodExtended3("moveToNextAttribute", (q_method_bool_t)XmlReader_moveToNextAttribute, false, QC_NO_FLAGS, QDOM_DEFAULT, boolTypeInfo);

    // *string XmlReader::name(){}
    QC_XMLREADER->addMethodExtended3("name", (q_method_t)XmlReader_name, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo);

    // *string XmlReader::namespaceUri(){}
    QC_XMLREADER->addMethodExtended3("namespaceUri", (q_method_t)XmlReader_namespaceUri, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo);

    // bool XmlReader::next(){}
    QC_XMLREADER->addMethodExtended3("next", (q_method_bool_t)XmlReader_next, false, QC_NO_FLAGS, QDOM_DEFAULT, boolTypeInfo);

    // int XmlReader::nodeType(){}
    QC_XMLREADER->addMethodExtended3("nodeType", (q_method_int64_t)XmlReader_nodeType, false, QC_CONSTANT, QDOM_DEFAULT, bigIntTypeInfo);

    // *string XmlReader::nodeTypeName(){}
    QC_XMLREADER->addMethodExtended3("nodeTypeName", (q_method_t)XmlReader_nodeTypeName, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo);

    // *string XmlReader::prefix(){}
    QC_XMLREADER->addMethodExtended3("prefix", (q_method_t)XmlReader_prefix, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo);

    // bool XmlReader::read(){}
    QC_XMLREADER->addMethodExtended3("read", (q_method_bool_t)XmlReader_read, false, QC_RET_VALUE_ONLY, QDOM_DEFAULT, boolTypeInfo);

    // bool XmlReader::readSkipWhitespace(){}
    QC_XMLREADER->addMethodExtended3("readSkipWhitespace", (q_method_bool_t)XmlReader_readSkipWhitespace, false, QC_RET_VALUE_ONLY, QDOM_DEFAULT, boolTypeInfo);

    // nothing XmlReader::relaxNGValidate(string relaxng){}
    QC_XMLREADER->addMethodExtended3("relaxNGValidate", (q_method_t)XmlReader_relaxNGValidate_Vs, false, QC_RET_VALUE_ONLY, QDOM_DEFAULT, nothingTypeInfo, 1, stringTypeInfo, NULL, "relaxng");

    // nothing XmlReader::schemaValidate(string xsd){}
    QC_XMLREADER->addMethodExtended3("schemaValidate", (q_method_t)XmlReader_schemaValidate_Vs, false, QC_RET_VALUE_ONLY, QDOM_DEFAULT, nothingTypeInfo, 1, stringTypeInfo, NULL, "xsd");

    // any XmlReader::toQore(){}
    QC_XMLREADER->addMethodExtended3("toQore", (q_method_t)XmlReader_toQore, false, QC_RET_VALUE_ONLY, QDOM_DEFAULT, anyTypeInfo);

    // any XmlReader::toQoreData(){}
    QC_XMLREADER->addMethodExtended3("toQoreData", (q_method_t)XmlReader_toQoreData, false, QC_RET_VALUE_ONLY, QDOM_DEFAULT, anyTypeInfo);

    // *string XmlReader::value(){}
    QC_XMLREADER->addMethodExtended3("value", (q_method_t)XmlReader_value, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo);

    // *string XmlReader::xmlLang(){}
    QC_XMLREADER->addMethodExtended3("xmlLang", (q_method_t)XmlReader_xmlLang, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo);

    // *string XmlReader::xmlVersion(){}
    QC_XMLREADER->addMethodExtended3("xmlVersion", (q_method_t)XmlReader_xmlVersion, false, QC_CONSTANT, QDOM_DEFAULT, stringOrNothingTypeInfo);

    return QC_XMLREADER;
}
